@@ -289,7 +289,7 @@ async def rabbit_c2_rpc_callback(
 async def connect_and_consume_rpc(main_config: dict, debug):
     connection = None
     global hostname
-    while True:
+    while connection is None:
         try:
             if debug:
                 print_flush("Connecting to rabbitmq in connect_and_consume_rpc")
@@ -301,28 +301,25 @@ async def connect_and_consume_rpc(main_config: dict, debug):
             )
             if debug:
                 print_flush("Successfully connected in connect_and_consume_rpc")
-            channel = await connection.channel()
-            # get a random queue that only the apfell server will use to listen on to catch all heartbeats
-            if debug:
-                print_flush("Declaring container specific rpc queue in connect_and_consume_rpc")
-            queue = await channel.declare_queue("{}_rpc_queue".format(hostname), auto_delete=True)
-            await channel.set_qos(prefetch_count=10)
-            try:
-                if debug:
-                    print_flush("Starting to consume callbacks in connect_and_consume_rpc")
-                task = queue.consume(
-                    partial(rabbit_c2_rpc_callback, channel.default_exchange)
-                )
-                result = await asyncio.gather(task)
-                if debug:
-                    print_flush("No longer consuming, starting loop again in connect_and_consume_rpc")
-            except Exception as e:
-                print_flush("Exception in connect_and_consume_rpc .consume: {}".format(str(e)))
         except (ConnectionError, ConnectionRefusedError) as c:
             print_flush("Connection to rabbitmq failed, trying again...")
         except Exception as e:
             print_flush("Exception in connect_and_consume_rpc connect: {}\n trying again...".format(str(e)))
         await asyncio.sleep(5)
+    channel = await connection.channel()
+    # get a random queue that only the apfell server will use to listen on to catch all heartbeats
+    if debug:
+        print_flush("Declaring container specific rpc queue in connect_and_consume_rpc")
+    queue = await channel.declare_queue("{}_rpc_queue".format(hostname), auto_delete=True)
+    await channel.set_qos(prefetch_count=10)
+    try:
+        if debug:
+            print_flush("Starting to consume callbacks in connect_and_consume_rpc")
+        task = queue.consume(
+            partial(rabbit_c2_rpc_callback, channel.default_exchange)
+        )
+    except Exception as e:
+        print_flush("Exception in connect_and_consume_rpc .consume: {}".format(str(e)))
 
 
 async def mythic_service(debug: bool):
